@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 73 $
+# Revision: $Rev: 92 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -23,15 +23,14 @@
 
 #-- imports --------------------------------------------------------------------
 #-- Qt imports
-from qt import SIGNAL, QListView, QListViewItem, QGridLayout
-from qt import PYSIGNAL, QImage, QPixmap
+from qt import SIGNAL, QListView, QListViewItem, QGridLayout, QSize, QTimer
+from qt import PYSIGNAL, QImage, QPixmap, QApplication
 
 
 #-- Python imports
 import logging
 import sys
 
-from types import ListType
 from os.path import exists as fexists
 
 
@@ -39,10 +38,9 @@ from os.path import exists as fexists
 from RecordListBase import RecordListBase
 from misc import correctSlice
 from AMCForm import AMCForm
-from AbstractFile import AbstractFileRecord
-from AMCFile33 import AMCRecord33
 from PicturePreview import PicturePreview
 from Settings import getPreferences
+from ListViewRecord import ListViewRecord
 
 # TODO: use C++ compiled version
 #from Qt.QListViewItemNumeric.QListViewItemNumeric import QListViewItemNumeric
@@ -52,6 +50,7 @@ from Settings import getPreferences
 pref = getPreferences(__name__)
 
 
+
 #-- About ListViews and RecordList --
 #
 # ListViews are strange objects. Originally RecordList should have
@@ -78,25 +77,18 @@ class RecordList(RecordListBase):
         formLayout = QGridLayout( self.frameRecord, 1,1 )
         formLayout.addWidget( self.form, 0,0 )
 
+        # list view
+        self.listViewRecord = ListViewRecord(self.frameListView)
+        listViewLayout = QGridLayout(self.frameListView, 1,1)
+        listViewLayout.addWidget( self.listViewRecord, 0,0 )
+
+        # image on left bottom
         self.image = PicturePreview( dirname, self.frameImage )
         imageLayout = QGridLayout( self.frameImage, 1,1 )
         imageLayout.addWidget( self.image, 0,0 )
 
-        self.listViewRecord.setAllColumnsShowFocus( True )
-        self.listViewRecord.setSorting( pref['sortColumn'] )
-        self.listViewRecord.setShowSortIndicator( True )
-        self.listViewRecord.setColumnWidthMode( 0, QListView.Manual )
-        self.listViewRecord.setColumnWidthMode( 1, QListView.Maximum )
-        self.listViewRecord.setResizeMode( QListView.LastColumn )
-        self.listViewRecord.setSelectionMode( QListView.Single )
-        self.listViewRecord.setDefaultRenameAction( QListView.Accept )
-
-        self.__obj = None               # keeps track of the last item added
-        self.__items = {}               # maps ListViewItem -> record
-
         self.connect( self.listViewRecord, SIGNAL("currentChanged(QListViewItem*)"), self.onCurrentChanged )
-        self.connect( self.listViewRecord, SIGNAL("itemRenamed(QListViewItem*,int,const QString&)"), self.onItemRenamed )
-        self.connect( self.form, PYSIGNAL("modified()"), self.onModified )
+        self.connect( self.form, PYSIGNAL("modified()"), self.listViewRecord.onModified )    
         # currently not needed: 
         # self.connect( self.image, PYSIGNAL("modified()"), self.onModified )
         
@@ -104,118 +96,62 @@ class RecordList(RecordListBase):
     #-- list interface ---------------------------------------------------------
     def add(self, rec):
         """W.add(rec) -- append record(s)"""
-        # add all new records
-        if (not type(rec) is ListType): rec = [rec]
-        obj = None
-        for r in rec:
-            if (not isinstance(r, AbstractFileRecord)):
-                r = AMCRecord33(r)
-            obj = QListViewItem( self.listViewRecord, *self.__compileTitles(r) )
-            obj.setRenameEnabled(0, True)
-            self.__items[obj] = r
-        # keep track of last item added
-        self.__obj = obj
-        
+        self.listViewRecord.add(rec)               
         # this also shows the main form when the first record becomes
         # available
-        if (obj != None): self.form.show()
+        if (len(self) != 0): self.form.show()
 
 
-    def iterkeys(self):
-        """returns iterator over all ListViewItems"""
-        return iter(self.__items.keys())
-
-    def itervalues(self):
-        """returns iterator over all records"""
-        return iter(self.__items.values())
-
-    def keys(self):
-        """returns an unsorted list of all keys"""
-        return self.__items.keys()
-
     def values(self):
         """returns an unsorted list of all records"""
-        return self.__items.values()
+        return self.listViewRecord.values()
 
-    def __delitem__(self, y):
+
+    def __delitem__(self, obj):
         """removes ListViewItem(s) by reference"""
-        self.log.debug("deleting record %s", y)
-        if (not type(y) is ListType): y = [y]
-        for obj in y:
-            self.listViewRecord.takeItem(obj)
-            del self.__items[obj]
+        del self.listViewRecord[obj]
+        if (len(self) == 0): self.form.hide()
+
 
     def __len__(self):
         """returns the number of elements in the list view"""
-        return len( self.__items.keys() )
+        return len(self.listViewRecord)
+
 
     def getCurrentRecord(self):
-        return self.__items[self.listViewRecord.currentItem()]
+        # here it is important that all instances: listViewRecord,
+        # form, image work on the same object;
+        return self.listViewRecord.getCurrentRecord()
 
-    def setCurrentRecord(self, record):
-        currentObj = self.listViewRecord.currentItem()
-        self.__items[currentObj] = record
-        self.onCurrentChanged(currentObj)
-        self.onModified()
+
+    def setCurrentRecord(self, record):        
+        self.listViewRecord.setCurrentRecord(record)
+        self.form.setRecord(record)
+        self.image.setRecord(record)
 
 
     #-- observer ---------------------------------------------------------------
     def onCurrentChanged(self, obj):
         """called when the \"current\" item changes"""
         if (obj != None):
-            self.form.setRecord( self.__items[obj] )
-            self.image.setRecord( self.__items[obj] )
+            record = self.listViewRecord.getCurrentRecord()
+            self.form.setRecord( record )
+            self.image.setRecord( record )
         else:
             self.form.setRecord(None)
             self.image.setRecord(None)
 
 
-    def onModified(self):
-        """called when a record is modified in the form"""
-        # update ListViewItem title
-        index = 0
-        record = self.__items[self.listViewRecord.currentItem()]
-        for text in self.__compileTitles(record):
-            self.listViewRecord.currentItem().setText(index, text)
-            index += 1
-
-
-    def onItemRenamed(self, obj, col, text):
-        """called when record number is modified in the list view"""
-        try:
-            number = int(unicode(text))
-        except ValueError:
-            pass
-        else:
-            self.__items[obj]['number'] = number
-        # update list view
-        self.onModified()
-        self.listViewRecord.sort()
-
-    
     #-- utility functions ------------------------------------------------------
-    def focus(self, obj):
-        """displays the object"""
-        if (obj != None):
-            self.listViewRecord.ensureItemVisible(obj)
-            self.listViewRecord.setCurrentItem(obj)
-            self.onCurrentChanged(obj)
-    
     def focusFirst(self):
         """displays the first item in the ListView"""
-        self.focus(self.listViewRecord.firstChild())
+        self.listViewRecord.focusFirst()
+
 
     def focusNew(self):
         """displays the last item added"""
-        self.focus(self.__obj)
+        self.listViewRecord.focusNew()
 
-    def __compileTitles(self, record):
-        """return a text-tuple what forms the ListViewItem entries """
-        num = unicode(record['number'])
-        if (pref['zeroPrefix_patch']):
-            num = u'0'*(4-len(num))+num
-        return (num,
-                record['mediaLabel'] or record['originalTitle'] or record['translatedTitle'])
         
     
 
@@ -234,7 +170,7 @@ if (__name__ == "__main__"):
     log.addHandler(hdlr) 
     log.setLevel(pref['logLevel'])
 
-    w = RecordList()
+    w = RecordList(".")
 
     from AMCFile33 import AMCFile33
     f = AMCFile33("Filme.amc", "rb")
