@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 84 $
+# Revision: $Rev: 93 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -24,7 +24,7 @@
 
 #-- imports --------------------------------------------------------------------
 #-- Qt imports --
-from qt import QApplication, QObject, SLOT, SIGNAL, QProcess, QDir
+from qt import QApplication, QObject, SLOT, SIGNAL, QProcess, QDir, PYSIGNAL
 from qt import QFileDialog, QMessageBox, QInputDialog, QLineEdit
 
 #-- Python imports --
@@ -48,8 +48,9 @@ from RecordList import RecordList
 from misc import YMD2Date
 from TitleMatchList import TitleMatchList
 from RecordPreview import RecordPreview
-from ScriptExecutionDialog import ScriptExecutionDialog
+from ScriptExecDialog import ScriptExecDialog
 from ScriptSelection import ScriptSelection
+from StdIOProcess import StdIOProcess
 
 
 #-- create logging and load preferences ----------------------------------------
@@ -61,7 +62,7 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("lmc.py - LMC Movie Catalogue  $Rev: 84 $ (c) by Uwe Mayer")
+log.info("lmc.py - LMC Movie Catalogue  $Rev: 93 $ (c) by Uwe Mayer")
 
 # load settings
 settings = Settings.Settings()
@@ -75,6 +76,14 @@ pref = Settings.getPreferences('__main__')
 log.setLevel(pref['logLevel'])
 
 
+#-- create proxy format for script environment
+scriptProxy = None
+if (pref['proxy'] != None):
+    scriptProxy = {}
+    for (k,v) in pref['proxy'].iteritems():
+        scriptProxy["%s_proxy"%k] = v        
+
+
 #-- used as filter in select movie to scan dialog
 movieFileFilter = [u'Movies (*.avi *.ogm *.mpg *.mpeg)',
                    u'All (*.*)']
@@ -130,10 +139,24 @@ class LMCMain(LMCWidgetBase):
         self.fileNewAction.setEnabled(True)
         self.connect(self.toolNewAction, SIGNAL("pressed()"), self.fileNew)
         self.toolNewAction.setEnabled(True)
-    
+
 
 
     #-- slot implementations ---------------------------------------------------
+    # connecting PYSIGNALs to the statusbar does not seem to work :(
+    # this this little wrapper
+    def updateStatusBar(self, message, delay=5000):
+        """updates status bar"""
+        self.statusBar().message(message, delay)
+
+
+    def closeEvent(self, e):
+        """called when application is closed: checks if file needs saving"""
+        if (self.__file != None):
+            self.fileClose()
+        e.accept()
+        
+
     def fileClose(self):
         """closes a file and removes the central widget"""
         self.log.info("Closing file %s", self.__file.name)
@@ -141,6 +164,8 @@ class LMCMain(LMCWidgetBase):
         self.__disableSaveCloseActions()
         if (len(self.centralWidget()) != 0): self.__disableMovieDeleteAction()
 
+        self.__querySaveOnDirty()
+      
         self.centralWidget().hide()
         self.setCentralWidget(None)
         self.__file.close()
@@ -341,6 +366,8 @@ class LMCMain(LMCWidgetBase):
         if (len(self.centralWidget()) > 0):
             self.__enableMovieDeleteAction()
 
+        self.connect( self.centralWidget().listViewRecord, PYSIGNAL("incSearchTextChanged"), self.updateStatusBar)
+
 
     def movieAdd(self):
         """adds a new movie record"""
@@ -391,18 +418,23 @@ class LMCMain(LMCWidgetBase):
 
     def movieGetLocalFromFiles(self):
         """get information from a file"""
-        filename = QFileDialog.getOpenFileName(
-            self.lastFolder, ";;".join(movieFileFilter), self,
+        # select filenames
+        filenames = QFileDialog.getOpenFileNames(
+            ";;".join(movieFileFilter), self.lastFolder, self,
             "scan file dialog", "Select file to scan")
-        if (filename == None): return
-        filename = unicode(filename.ascii(), pref['systemEncoding'])
+        if (filenames == None): return
+        filenames = map(lambda a: unicode(a.ascii(), pref['systemEncoding']), filenames)
+
         # quit if nothing selected
-        if (filename == ""): return
+        if (len(filenames) == 0): return
+
         # remember last directory
-        self.lastFolder = dirname(filename)
+        self.lastFolder = dirname(filenames[0])
+
         # get media info
-        self.log.info("getting file information for %s using %s", basename(filename), pref['mediaInfo'])
-        info = pref['mediaInfo'](filename)
+        self.log.info("getting file information for %s using %s", basename(filenames[0]), pref['mediaInfo'])
+        info = pref['mediaInfo'](filenames[0])
+        info.scan()
 
         record = self.centralWidget().getCurrentRecord()
         record['originalTitle'] = info.originalTitle
@@ -414,8 +446,18 @@ class LMCMain(LMCWidgetBase):
         record['videoBitrate'] = info.videoBitrate
         record['audioBitrate'] = info.audioBitrate
         record['framerate'] = info.framerate
-        record['fileSize'] = "+".join([record['fileSize'], info.getFileSize(MediaInfo.MB)])
+        if (record['fileSize'] != ""):
+            record['fileSize'] = "+".join([record['fileSize'], info.getFileSize(MediaInfo.MB)])
+        else:
+            record['fileSize'] = info.getFileSize(MediaInfo.MB)
         record['length'] = info.length
+        record['discs'] += 1
+
+        # get detailed info on first file; for all others just adjust
+        # filesize
+        for filename in filenames[1:]:
+            record['fileSize'] += "+%s"%info.normalizeFileSize(fsize(filename), MediaInfo.MB)
+        
         self.centralWidget().setCurrentRecord(record)
 
 
@@ -428,7 +470,6 @@ class LMCMain(LMCWidgetBase):
         # remember usual default target path
         tmp = self.lastFolder
         self.lastFolder = pref['autoMountPoint']
-        
         # get info
         self.movieGetLocalFromFiles()
         
@@ -485,10 +526,8 @@ class LMCMain(LMCWidgetBase):
             self.log.info("Getting title list from %s", script[0])
 
             # execute script for title matches
-            titleSearchProcess = QProcess(script[0])
-            titleSearchProcess.setWorkingDirectory(QDir(pref['scriptPath']))
-            titleSearchProcess.addArgument(unicode(searchTitle).encode(pref['systemEncoding']))
-            execDlg = ScriptExecutionDialog(titleSearchProcess, modal=True)
+            titleSearch = StdIOProcess(script[0], [searchTitle.encode(pref['systemEncoding'])], scriptProxy, pref['scriptPath'])
+            execDlg = ScriptExecDialog(titleSearch, modal=True)
 
             # if process was aborted, stop
             if (execDlg.exec_loop() == execDlg.Rejected):
@@ -496,14 +535,14 @@ class LMCMain(LMCWidgetBase):
                 continue
         
             # process child error output
-            if (execDlg.stderr() != ""):
+            if (titleSearch.stderr() != ""):
                 log = logging.getLogger(script[0])
-                log.error(execDlg.stderr())
+                log.error(titleSearch.stderr())
                 return
             
             # remember list of title matches or details
             # (whatever was returned)
-            stdoutText = execDlg.stdout()
+            stdoutText = titleSearch.stdout()
 
             # parse output from search for matched titles
             titleMatchDlg = TitleMatchList(self)
@@ -527,10 +566,8 @@ class LMCMain(LMCWidgetBase):
                 url = titleMatchDlg.selectedItem()
 
                 # fetch details
-                detailSearchProcess = QProcess(script[0])
-                detailSearchProcess.setWorkingDirectory(QDir(pref['scriptPath']))
-                detailSearchProcess.addArgument(unicode(url).encode(pref['systemEncoding']))
-                execDlg2 = ScriptExecutionDialog(detailSearchProcess, modal=True)
+                detailSearch = StdIOProcess(script[0], [url.encode(pref['systemEncoding'])], scriptProxy, pref['scriptPath'])
+                execDlg2 = ScriptExecDialog(detailSearch, modal=True)
                 
                 # if process was aborted, stop
                 if (execDlg2.exec_loop() == execDlg2.Rejected):
@@ -538,13 +575,13 @@ class LMCMain(LMCWidgetBase):
                     continue
 
                 # process child error output
-                if (execDlg2.stderr() != ""):
+                if (detailSearch.stderr() != ""):
                     log = logging.getLogger(script[0])
-                    log.error(execDlg2.stderr())
+                    log.error(detailSearch.stderr())
                     return
                 
                 # remember details
-                stdoutText = execDlg2.stdout()
+                stdoutText = detailSearch.stdout()
 
             # exclude invalid fields
             stdoutLines = filter(lambda a: a[:a.find(':')] in script[1:], stdoutText.split("\n"))
@@ -568,7 +605,8 @@ class LMCMain(LMCWidgetBase):
         for f in new.keys():
             record[f] = new[f]
         self.centralWidget().setCurrentRecord(record) # display new values
-        self.centralWidget().image.getRecord(forceDecode=True)
+        if (new.has_key('picture')): 
+            self.centralWidget().image.imageDecode()
                     
 
 
@@ -728,7 +766,9 @@ class LMCMain(LMCWidgetBase):
 
 #-- main program ---------------------------------------------------------------
 app = QApplication(sys.argv)
+
 QObject.connect(app, SIGNAL("lastWindowClosed()"), app, SLOT("quit()"))
+
 main = LMCMain()
 app.setMainWidget(main)
 main.show()
