@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 # Author:   $Author: merkosh $
-# Revision: $Rev: 759 $
+# Revision: $Rev: 88 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -18,7 +18,7 @@
 #    You should have received a copy of the GNU General Public License     #
 #    along with this program; if not, write to the                         #
 #    Free Software Foundation, Inc.,                                       #
-#    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          #
+#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
 ############################################################################
 
 #---------------------------------------------------------#
@@ -31,7 +31,6 @@ use LWP::UserAgent;
 use HTTP::Request;
 use HTML::Entities;
 use File::Basename;
-use POSIX qw(ceil);
 
 use LMCTools;
 
@@ -103,8 +102,8 @@ if ($title) {
   #-- get list of titles
   $page = getPage($searchURL.uri_escape($title))->content();
 
-  @sections = ("Titles (Exact Matches)", "Popular Titles", 
-	       "Titles (Partial Matches)", "Titles (Approx Matches)");
+  @sections = ("Popular Titles", "Titles (Exact Matches)",
+	       "Titles (Partial Matches)");
   %match = ();
   $totalResults = 0;
   $pos = 0;
@@ -119,19 +118,12 @@ if ($title) {
       $text =~ /Displaying (\d+) Result/;
       $count = $1;
       for ($i=0; $i < $count; $i++){
-	$pos = index($text, "href=\"/title/");
-	$text = substr($text, $pos);
-# changed: 2007-08-04 
-# 	$text =~ /href\=\"(\/title\/.+?\/)\?.+?\"\>(.+?)\<\/a\> +(\(.+?\))(.*?)\<\/td\>/;
-	$text =~ /href\=\"(\/title\/.+?\/)\"\>(.+?)\<\/a\> +(\(.+?\))\</;
-
-# changed: 2007-08-04 
-# 	push @{$match{$sec}}, {URL => $1, Text => decode_entities("$2 $3"), 
-# 			       Comment => &unfiddleAka(decode_entities($4))};
-	push @{$match{$sec}}, {URL => $1, Text => decode_entities("$2 $3")};
+	$pos = index($text, "<li>");
+	$text = substr($text, $pos+1);
+	$text =~ /href\=\"(\/title\/.+?\/)\?.+?\"\>(.+?)\<\/a\> +(\(.+?\))(.*?)\<\/li\>/;
+	push @{$match{$sec}}, {URL => $1, Text => decode_entities("$2 $3"), 
+			       Comment => &unfiddleAka(decode_entities($4))};
 	$totalResults++;
-
-	$text = substr($text, 1);
       }
     }
   }
@@ -150,10 +142,9 @@ if ($title) {
       foreach $rec (@{$match{$sec}}){
 	print "title: $rec->{Text}\n";
 	print "url: $baseURL$rec->{URL}\n";
-# changed: 2007-08-04 
-# 	foreach $desc (@{$rec->{Comment}}){
-# 	  print "description: $desc\n";
-# 	}
+	foreach $desc (@{$rec->{Comment}}){
+	  print "description: $desc\n";
+	}
 	print "\n";
       }
     }
@@ -192,15 +183,15 @@ if ($URL){
   # - producer
 
   # original title
-  $tmp = &find($page, '<h1>');
+  $tmp = &find($page, '<strong class="title">');
   $data{'originalTitle'} = decode_entities($1) if ($tmp =~ /\>([^\<]+) *\</);
 
   # year
-  $tmp = &find($tmp, '<span>');
+  $tmp = &find($tmp, '<small>');
   $data{year} = $1 if ($tmp =~ /href\=.+?\>(\d+)\</);
 
   # picture
-  $tmp = &find($page, '<a name="poster"');
+  $tmp = &find($page, ' alt="cover" ');
   # if image found
   if ($tmp){
     $tmp =~ /src=\"(.+?)\"/;
@@ -218,48 +209,37 @@ if ($URL){
   }
 
   # director
-  $tmp = &find($page, '<h5>Director');
-  @director = ();
-  if ($tmp) {
-    do {
-      $tmp =~ /href\=.+?\>([^\<]+?)\</;
-      push @director, decode_entities($1);
-      $tmp = &find($tmp, $1);
-    } while (index($tmp, "<a href=") < index($tmp, "</div>"));
-
-    $data{director} = join(", ", @director) if (scalar @director);
-  }
+  $tmp = &find($page, 'Directed by</b>');
+  $data{director} = decode_entities($1) if ($tmp =~ /href\=.+?\>([^\<]+?)\</);
 
   # category
-  $tmp = &find($page, '<h5>Genre:');
+  $tmp = &find($page, '<b class="ch">Genre:</b>');
   @category = ();
-  if ($tmp) {
-    do {
-      $tmp =~ /href\=.+?\>([^\<]+?)\</;
-      push @category, decode_entities($1);
-      $tmp = &find($tmp, $1);
-    } while (index($tmp, "<a href=") < index($tmp, "</div>"));
-    
-    $data{category} = join(", ", @category) if (scalar @category);
+  while ($tmp){
+    $tmp = &find($tmp, '<a href="/Sections/Genres/', 1);
+    last unless ($tmp);
+    $tmp =~ /\>(.+?)\</;
+    push @category, decode_entities($1);
   }
-      
+  $data{category} = join(", ", @category) if (scalar @category);
+
   # actors
-  $tmp = &find($page, 'header_cast.gif');
+  $tmp = &find($page, '<b class="blackcatheader">Cast overview');
   @actors = ();
-  do {
+  while ($tmp){
     $tmp = &find($tmp, '<a href="/name/', 1);
-    $tmp =~ /\>(.+?)\<.+?\<td class\=\"char\"\>(.+?)\<\//;
+    last unless ($tmp);
+    $tmp =~ /\>(.+?)\<.+?\.\.\.\. .+?\"\>(.+?)\<\/td\>/;
     push @actors, decode_entities($1)." - ".decode_entities($2);
-    $tmp = &find($tmp, $1);
-  } while (index($tmp, "<a href=") < index($tmp, "</div>"));
+  }
   $data{actors} = \@actors if (scalar @actors);
 
   # rating
-  $tmp = &find($page, '<b>User Rating:</b>');
+  $tmp = &find($page, '<b class="ch">User Rating:</b>');
   # if no rating available (first 100 char contain magic text)
   if (substr($tmp, 0, 100) !~ /awaiting \d votes/) {
     $tmp = &find($tmp, '<b>');
-    $data{rating} = ceil($1) if ($tmp =~ /([\d\.]+?)\//);
+    $data{rating} = $1 if ($tmp =~ /([\d\.]+)/);
   }
 
   # url
@@ -268,51 +248,32 @@ if ($URL){
   $data{url} = $URL;
 
   # length
-  $tmp = &find($page, '<h5>Runtime:</h5>');
+  $tmp = &find($page, '<b class="ch">Runtime:</b>');
   $data{length} = $1 if ($tmp =~ /(\d+) min/);
 
   # country
-  $tmp = &find($page, '<h5>Country:</h5>');
-  @country = ();
-  do {
-    $tmp =~ /href\=\".+?\"\>(.+?)\</;
-    push @country, decode_entities($1);
-    $tmp = &find($tmp, $1);
-  } while (index($tmp, "<a href=") < index($tmp, "</div>"));
-  $data{country} = join(", ", @country) if (scalar @country);
+  $tmp = &find($page, '<b class="ch">Country:</b>');
+  $data{country} = decode_entities($1) if ($tmp =~ /href\=\".+?\"\>(.+?)\</);
 
   # language
-  $tmp = &find($page, '<h5>Language:</h5>');
-  @languages = ();
-  do {
-    $tmp =~ /href\=\".+?\"\>(.+?)\</;
-    push @languages, decode_entities($1);
-    $tmp = &find($tmp, $1);
-  } while (index($tmp, "<a href=") < index($tmp, "</div>"));
-  $data{languages} = join(", ", @languages) if (scalar @languages);
+  $tmp = &find($page, '<b class="ch">Language:</b>');
+  $data{languages} = decode_entities($1) if ($tmp =~ /href\=\".+?\"\>(.+?)\</);
 
   # description
   $tmp = &getPage($URL.'plotsummary')->content();
   @summary = ();
-  do {
+  while ($tmp){
     $tmp = &find($tmp, '<p class="plotpar">', 1);
-    if ($tmp) {
-      $tmp =~ /\>(.+?)\<\/p\>/s;
-      push @summary, &strip(decode_entities($1));
-      $summary[-1] =~ s/\<a href\=.+?\>//;
-      $summary[-1] =~ s/\<\/a\>//;
-      $summary[-1] =~ s/\<i\>//;
-      $summary[-1] =~ s/\<\/i\>//;
-      $summary[-1] =~ s/\n+/\n/;
-      $summary[-1] =~ s/\n/<br>/g;
-      $tmp = substr($tmp,1);
-    }
-  } while (index($tmp, '<p class="plotpar">') < index($tmp, '<div '));
+    last unless ($tmp);
+    $tmp =~ /\>(.+?)\<\/p\>/s;
+    push @summary, &strip(decode_entities($1));
+    $summary[-1] =~ s/\n/<br>/g;
+  }
   $data{description} = \@summary if (scalar @summary);
 
   # comments
-  $tmp = &find($page, '<div class="comment">');
-  $tmp = &find($tmp, 'Author:');
+  $tmp = &find($page, '<a name="comment">User Comments:</a>');
+  $tmp = &find($tmp, '<small>Author:</small>');
   $tmp = &find($tmp, '<p>');
   $tmp =~ /\>(.+?)\<\/p\>/s;
   if ($1) {
